=== modified file 'bzrlib/errors.py'
--- bzrlib/errors.py	2011-08-21 13:49:30 +0000
+++ bzrlib/errors.py	2011-09-05 10:28:30 +0000
@@ -2349,6 +2349,14 @@
     """
 
 
+class GhostTagsNotSupported(BzrError):
+
+    _fmt = "Ghost tags not supported by format %(format)r."
+
+    def __init__(self, format):
+        self.format = format
+
+
 class BinaryFile(BzrError):
 
     _fmt = "File is binary but should be text."

=== modified file 'bzrlib/tag.py'
--- bzrlib/tag.py	2011-09-05 10:25:09 +0000
+++ bzrlib/tag.py	2011-09-05 10:28:30 +0000
@@ -44,6 +44,13 @@
 
 class _Tags(object):
 
+    # Whether this tag container versions tags
+    versioned = False
+
+    # Does this tag container support references to revisions
+    # that are not present in the branch repository?
+    supports_ghosts = True
+
     def __init__(self, branch):
         self.branch = branch
 
@@ -74,6 +81,8 @@
 
         :param tag_name: Tag name
         :param revision: Revision id
+        :raise GhostTagsNotSupported: if revision is not present in
+            the branch repository
         """
         raise NotImplementedError(self.set_tag)
 

=== modified file 'doc/en/release-notes/bzr-2.5.txt'
--- doc/en/release-notes/bzr-2.5.txt	2011-09-02 12:45:36 +0000
+++ doc/en/release-notes/bzr-2.5.txt	2011-09-05 10:28:30 +0000
@@ -221,6 +221,10 @@
   value in SI format (i.e. "20MB", "1GB") into its integer equivalent. 
   (Shannon Weyrick)
 
+* ``Tags`` containers can now declare whether they support versioned
+  tags and whether tags can refer to ghost tags.
+  (Jelmer Vernooij)
+
 * ``Tags.merge_to`` now returns a dictionary with the updated tags
   and a set of conflicts, rather than just conflicts. (Jelmer Vernooij)
 

